/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMECURSORS "pygame module for cursor resources"
#define DOC_PYGAMECURSORSCOMPILE "compile(strings, black='X', white='.', xor='o') -> data, mask\ncreate binary cursor data from simple strings"
#define DOC_PYGAMECURSORSLOADXBM "load_xbm(cursorfile) -> cursor_args\nload_xbm(cursorfile, maskfile) -> cursor_args\nload cursor data from an XBM file"
#define DOC_PYGAMECURSORSCURSOR "Cursor(size, hotspot, xormasks, andmasks) -> Cursor\nCursor(hotspot, surface) -> Cursor\nCursor(constant) -> Cursor\nCursor(Cursor) -> Cursor\nCursor() -> Cursor\npygame object representing a cursor"
#define DOC_CURSORCOPY "copy() -> Cursor\ncopy the current cursor"
#define DOC_CURSORTYPE "type -> string\nGets the cursor type"
#define DOC_CURSORDATA "data -> tuple\nGets the cursor data"


/* Docs in a comment... slightly easier to read. */

/*

pygame.cursors
pygame module for cursor resources

pygame.cursors.compile
 compile(strings, black='X', white='.', xor='o') -> data, mask
create binary cursor data from simple strings

pygame.cursors.load_xbm
 load_xbm(cursorfile) -> cursor_args
 load_xbm(cursorfile, maskfile) -> cursor_args
load cursor data from an XBM file

pygame.cursors.Cursor
 Cursor(size, hotspot, xormasks, andmasks) -> Cursor
 Cursor(hotspot, surface) -> Cursor
 Cursor(constant) -> Cursor
 Cursor(Cursor) -> Cursor
 Cursor() -> Cursor
pygame object representing a cursor

pygame.cursors.Cursor.copy
 copy() -> Cursor
copy the current cursor

pygame.cursors.Cursor.type
 type -> string
Gets the cursor type

pygame.cursors.Cursor.data
 data -> tuple
Gets the cursor data

*/